{% extends 'lastfm/base.html' %}

{% block breadcrumbs %}
    <li class="breadcrumb-item"><a href="{% url 'ditto:home' %}">Home</a></li>
    <li class="breadcrumb-item"><a href="{% url 'lastfm:home' %}">Last.fm</a></li>
    <li class="breadcrumb-item"><a href="{% url 'lastfm:user_detail' username=account.username %}">{{ account.realname }}</a></li>
    <li class="breadcrumb-item active">Albums</li>
{% endblock %}

{% block content %}
    {% load ditto_core %}
    {% current_url_name as url_name %}

    <h1 class="my-4">
        <a href="{% url 'lastfm:user_detail' username=account.username %}">
            {{ account.realname }}
        </a><br>
        {% block title %}
            Albums
        {% endblock %}
    </h1>

    <div class="row">
        <div class="col-md-3">
            {% include 'lastfm/includes/page_navigation.html' with request=request url_name=url_name counts=counts account=account only %}
        </div> <!-- .col -->

        <div class="col-md-9">
            {% include 'lastfm/includes/day_filter.html' with request=request current_days=current_days valid_days=valid_days only %}

            {% include 'lastfm/includes/chart.html' with object_list=album_list chart_type='albums' page_obj=page_obj request=request only %}
        </div> <!-- .col -->
    </div> <!-- .row -->

{% endblock content %}

