# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-13 16:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("twitter", "0043_remove_media_is_private"),
    ]

    operations = [
        migrations.AlterField(
            model_name="tweet", name="text", field=models.TextField(),
        ),
    ]
