# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-03 14:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("flickr", "0011_auto_20160502_1645"),
    ]

    operations = [
        migrations.AlterField(
            model_name="photoset",
            name="flickr_id",
            field=models.BigIntegerField(db_index=True, unique=True),
        ),
        migrations.AlterField(
            model_name="photoset",
            name="photo_count",
            field=models.PositiveIntegerField(
                default=0, help_text="The number of photos in the set on Flickr"
            ),
        ),
        migrations.AlterField(
            model_name="photoset",
            name="video_count",
            field=models.PositiveIntegerField(
                default=0, help_text="The number of videos in the set on Flickr"
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="nsid",
            field=models.CharField(
                db_index=True, max_length=50, unique=True, verbose_name="NSID"
            ),
        ),
    ]
