# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-28 15:42
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("pinboard", "0021_auto_20160428_1533"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bookmark",
            name="url",
            field=models.TextField(validators=[django.core.validators.URLValidator()]),
        ),
        migrations.AlterField(
            model_name="bookmark",
            name="url_hash",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Slug in the Bookmark's local URL.",
                max_length=12,
            ),
        ),
    ]
