# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-03 14:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("twitter", "0042_auto_20160603_1422"),
    ]

    operations = [
        migrations.RemoveField(model_name="media", name="is_private",),
    ]
